@@ -1,7 +1,10 @@
-getBioMartData<-function(genes,verbose=FALSE) {
-    mart = useMart("ensembl", dataset="hsapiens_gene_ensembl")
-    listMarts(mart)[grep("ensembl",listMarts(mart)[,1]),]
-    listDatasets(mart)[grep("hsapien",listDatasets(mart)[,1]),]
+getBioMartData<-function(genes,verbose=FALSE,...) {
+    dots <- list(...)
+    if(length(dots)==0){
+      mart = useMart("ensembl", dataset="hsapiens_gene_ensembl")
+    } else {
+      mart = useMart(...)
+    }
 
     geneattr<-c("hgnc_symbol","chromosome_name","start_position","end_position")
 
